@@ -40,7 +40,7 @@ options(
         # python-2.5 distutils we can add these:
         #   for bodhi (koji yum)
         #   pycurl
-        install_requires=['simplejson'],
+        install_requires=['bunch', 'kitchen'],
         # And these to extra_require:
         #   for widgets: (bugzilla feedparser)
         extras_require = {
@@ -61,6 +61,8 @@ options(
                 'main = fedora.wsgi.test.testapp:make_app'),
             'paste.app_install' : (
                 'main = pylons.util:PylonsInstaller'),
+	    'paste.filter_app_factory': (
+		'faswho = fedora.wsgi.faswho:make_faswho_middleware')
             },
         message_extractors = {
             'fedora': [('**.py', 'python', None),
@@ -74,6 +76,9 @@ options(
             'Intended Audience :: System Administrators',
             'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
             'Programming Language :: Python :: 2.4',
+            'Programming Language :: Python :: 2.5',
+            'Programming Language :: Python :: 2.6',
+            'Programming Language :: Python :: 2.7',
             'Topic :: Internet :: WWW/HTTP',
             'Topic :: Software Development :: Libraries :: Python Modules',
             ],
